/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package example.filesystem;

import org.apache.ws.resource.PropertiesResource;
import org.apache.ws.resource.Resource;
import org.apache.ws.resource.example.filesystem.FileSystemPropertiesDocument;
import org.apache.ws.resource.lifetime.ResourceLifetime1_2Constants;
import org.apache.ws.resource.lifetime.ScheduledResourceTerminationResource;
import org.apache.ws.resource.lifetime.callback.CurrentTimeCallback;
import org.apache.ws.resource.properties.ResourceProperty;
import org.apache.ws.resource.properties.ResourcePropertySet;
import org.apache.ws.resource.properties.XmlBeansResourcePropertyUtils;
import org.apache.ws.resource.properties.impl.XmlBeansResourceProperty;
import org.apache.ws.resource.properties.impl.XmlBeansResourcePropertySet;
import org.oasisOpen.docs.wsrf.x2004.x06.wsrfWSResourceLifetime12Draft01.CurrentTimeDocument;
import org.oasisOpen.docs.wsrf.x2004.x06.wsrfWSResourceLifetime12Draft01.TerminationTimeDocument;

import java.util.Calendar;

/**
 * An abstract filesystem WS-Resource.
 * <p/>
 * NOTE: This class is generated and is NOT meant to be modified.
 *
 * @author Ian P. Springer
 * @author Sal Campana
 */
public abstract class AbstractFileSystemResource implements Resource, PropertiesResource, ScheduledResourceTerminationResource
{
    /**
     * The resource ID of the instance.
     */
    protected String m_id;

    /**
     * The ResourceProperty Set containing the resource props.
     */
    protected ResourcePropertySet m_propSet;

    /**
     * Returns the current time from the prop set.
     *
     * @return Calendar
     */
    public Calendar getCurrentTime()
    {
        return XmlBeansResourcePropertyUtils.getDateTimePropertyValue( (XmlBeansResourceProperty) m_propSet.get( ResourceLifetime1_2Constants.PROP_QNAME_CURRENT_TIME ) );
    }

    /**
     * DOCUMENT_ME
     *
     * @param id DOCUMENT_ME
     */
    public void setID( Object id )
    {
        if ( m_id != null )
        {
            throw new IllegalStateException( "This resource's ID has already been set." );
        }

        try
        {
            m_id = (String) id;
        }
        catch ( ClassCastException cce )
        {
            throw new IllegalArgumentException( "Specified ID is not a String." );
        }
    }

    /**
     * DOCUMENT_ME
     *
     * @return DOCUMENT_ME
     */
    public Object getID()
    {
        return m_id;
    }

    /**
     * @see org.apache.ws.resource.PropertiesResource#setResourcePropertySet(org.apache.ws.resource.properties.ResourcePropertySet)
     */
    public void setResourcePropertySet( ResourcePropertySet propSet )
    {
        m_propSet = propSet;
    }

    /**
     * @see org.apache.ws.resource.PropertiesResource#getResourcePropertySet()
     */
    public ResourcePropertySet getResourcePropertySet()
    {
        return m_propSet;
    }

    /**
     * DOCUMENT_ME
     *
     * @param time DOCUMENT_ME
     */
    public void setTerminationTime( Calendar time )
    {
        XmlBeansResourcePropertyUtils.setDateTimePropertyValue( (XmlBeansResourceProperty) getResourcePropertySet().get( ResourceLifetime1_2Constants.PROP_QNAME_TERMINATION_TIME ),
                time );
    }

    /**
     * DOCUMENT_ME
     *
     * @return DOCUMENT_ME
     */
    public Calendar getTerminationTime()
    {
        return XmlBeansResourcePropertyUtils.getDateTimePropertyValue( (XmlBeansResourceProperty) m_propSet.get( ResourceLifetime1_2Constants.PROP_QNAME_TERMINATION_TIME ) );
    }

    public void destroy()
    {
        return;
    }

    public void init()
    {
        FileSystemPropertiesDocument propsDoc = FileSystemPropertiesDocument.Factory.newInstance();
        m_propSet = new XmlBeansResourcePropertySet( propsDoc );

        ResourceProperty prop = m_propSet.get( ResourceLifetime1_2Constants.PROP_QNAME_CURRENT_TIME );
        CurrentTimeDocument currTime = CurrentTimeDocument.Factory.newInstance();
        currTime.setCurrentTime( Calendar.getInstance() );
        prop.add( currTime );
        prop.setCallback( new CurrentTimeCallback() );

        prop = m_propSet.get( ResourceLifetime1_2Constants.PROP_QNAME_TERMINATION_TIME );
        TerminationTimeDocument termTime = TerminationTimeDocument.Factory.newInstance();
        termTime.setNilTerminationTime();
    }
}
